import uuid

from django.db import models


class BaseModel(models.Model):
    """
    Abstract model used when creating models in the project.

    Uses an UUID4 as primary key field and adds a created_at, modified_at
    fields.
    """
    id = models.UUIDField(default=uuid.uuid4, primary_key=True, editable=False)
    created_at = models.DateTimeField(auto_now_add=True)
    modified_at = models.DateTimeField(auto_now=True)

    class Meta:
        abstract = True
